"""
.. module:: __init__
   :synopsis: General Sitri class
.. moduleauthor:: Aleksander Lavrov <github.com/egnod>
"""

from sitri.configurator import SitriProviderConfigurator

Sitri = SitriProviderConfigurator
